@@ -4,8 +4,9 @@ CHECK = "✓"
 ARROW = "→"
 QUOTE = '"'
 NEW_LINE = "\n"
+ANIMATION_SLEEP = 1.5
 MATCH_REF = "reference"
-CACHE_REGEX = r"\"\$\((?P<reference>.*?)\)\""
+CACHE_REF = r"\$\((?P<reference>.*?)\)"
 
 USER_ENV_PATH = ".env*"
 USER_PIPFILE_PATH = "Pipfile"
